package Acme::MetaSyntactic::antlers;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::antlers - The antler theme

=head1 DESCRIPTION

Kinds of moose and other antlered, er, moose.

=head1 CONTRIBUTOR

Gaal Yahas.

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-10-31

Introduced in Acme-MetaSyntactic version 0.46.

=item *

2005-09-16

Submitted by Gaal Yahas.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
moose elk caribou wapiti alces_alces deer hirvi eland oryx antler
velvet_antler
